# celestial_tools
[![CircleCI](https://circleci.com/gh/PseudoDesign/celestial_tools.svg?style=svg)](https://circleci.com/gh/PseudoDesign/celestial_tools)
[![codecov](https://codecov.io/gh/PseudoDesign/celestial_tools/branch/master/graph/badge.svg)](https://codecov.io/gh/PseudoDesign/celestial_tools)
[![Documentation Status](https://readthedocs.org/projects/celestial-tools/badge/?version=latest)](https://celestial-tools.readthedocs.io/en/latest/?badge=latest)


See the above links for documentation.
